@@ -8,39 +8,39 @@ import time
 
 class PyTorReq(object):
     def __init__(self, proxy_port=9050, ctrl_port=9051, password=None, torPath='tor', debug=False):
-        self.proxyPort = proxy_port
-        self.ctrlPort = ctrl_port
-        self.torPath = torPath
-        self.password = password
+        self.__proxyPort = proxy_port
+        self.__ctrlPort = ctrl_port
+        self.__torPath = torPath
+        self.__password = password
         self._tor_proc = None
-        self.ctrl = None
+        self.__ctrl = None
         self.session = None
-        self.debug = debug
+        self.__debug = debug
 
     def launchTorSession(self):
-        if self.debug:
-            print(f'Launch new tor session on {self.proxyPort} proxy port, {self.ctrlPort} ctrl port.')
+        if self.__debug:
+            print(f'Launch new tor session on {self.__proxyPort} proxy port, {self.__ctrlPort} ctrl port.')
         if not self._torProcessExists():
             self._tor_proc = self._launchTor()
-        self.ctrl = Controller.from_port(port=self.ctrlPort)
-        self.ctrl.authenticate(password=self.password)
+        self.__ctrl = Controller.from_port(port=self.__ctrlPort)
+        self.__ctrl.authenticate(password=self.__password)
         self.session = requests.Session()
         self.session.proxies.update({
-            'http': f'socks5://localhost:{self.proxyPort}',
-            'https': f'socks5h://localhost:{self.proxyPort}',
+            'http': f'socks5://localhost:{self.__proxyPort}',
+            'https': f'socks5h://localhost:{self.__proxyPort}',
         })
 
     def _torProcessExists(self):
         try:
-            ctrl = Controller.from_port(port=self.ctrlPort)
+            ctrl = Controller.from_port(port=self.__ctrlPort)
             ctrl.close()
             return True
         except:
             return False
 
     def _launchTor(self):
-        return launch_tor_with_config(config={'SocksPort': str(self.proxyPort), 'ControlPort': str(self.ctrlPort)},
-                                      take_ownership=True, tor_cmd=self.torPath)
+        return launch_tor_with_config(config={'SocksPort': str(self.__proxyPort), 'ControlPort': str(self.__ctrlPort)},
+                                      take_ownership=True, tor_cmd=self.__torPath)
 
     def close(self):
         try:
@@ -48,7 +48,7 @@ class PyTorReq(object):
         except:
             pass
         try:
-            self.ctrl.close()
+            self.__ctrl.close()
         except:
             pass
         if self._tor_proc:
@@ -56,19 +56,19 @@ class PyTorReq(object):
 
     def getNewTorIdentity(self):
         try:
-            if self.debug:
+            if self.__debug:
                 print('Send signal to tor process, NEWNYM, closing session.')
-            self.ctrl.signal(Signal.NEWNYM)
-            self.ctrl.close()
+            self.__ctrl.signal(Signal.NEWNYM)
+            self.__ctrl.close()
             self.launchTorSession()
         except:
             print(
                 'TOR : The connection is not established. the destination computer rejected the connection request.'
                 ' Trying to reconnect.')
-            self.ctrl.close()
+            self.__ctrl.close()
             self.launchTorSession()
             self.getNewTorIdentity()
-        time.sleep(self.ctrl.get_newnym_wait())
+        time.sleep(self.__ctrl.get_newnym_wait())
 
     def get(self, *args, **kwargs):
         return self.session.get(*args, **kwargs)
